.. _combinatorics-graycode:

Gray Code
=========

.. module:: sympy.combinatorics.graycode

.. autoclass:: GrayCode
   :members:

.. automethod:: sympy.combinatorics.graycode.random_bitstring

.. automethod:: sympy.combinatorics.graycode.gray_to_bin

.. automethod:: sympy.combinatorics.graycode.bin_to_gray

.. automethod:: sympy.combinatorics.graycode.get_subset_from_bitstring

.. automethod:: sympy.combinatorics.graycode.graycode_subsets
